@@ -161,8 +161,8 @@ int main(int argc, char **argv)
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     KontactApp app(argc, &argv);
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
     KCrash::initialize();
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kontact"));
